@@ -119,7 +119,7 @@ def example(path):
 def raw(path):
     """print pipeline input example (raw data)"""
     meta = Pipeline.load_meta(path)
-    click.echo(json.dumps(meta[RAW], indent=4))
+    click.echo(json.dumps(meta.get(RAW), indent=4))
 
 
 @main.command()
@@ -127,7 +127,7 @@ def raw(path):
 def variables(path):
     """print pipeline variables"""
     meta = Pipeline.load_meta(path)
-    click.echo(json.dumps(process_variables(meta[VARIABLES]), indent=4))
+    click.echo(json.dumps(process_variables(meta.get(VARIABLES)), indent=4))
 
 
 @main.command()
@@ -140,7 +140,7 @@ def packages(path):
 
 @main.command()
 @click.argument("path", type=click.Path(exists=True))
-@click.option("--output", type=click.Path())
+@click.option('-o', "--output", type=click.Path())
 def freeze(path, output=None):
     """write pipeline packages to a file (pip freeze > output)"""
     meta = Pipeline.load_meta(path)
@@ -179,9 +179,10 @@ def build(path, name="goldilox", image=None, dockerfile=None, platform=None):
         python_version = meta.get(PY_VERSION)
         venv_type = meta.get(VENV_TYPE)
         goldilox_version = meta.get(VERSION)
+        is_conda = venv_type == 'conda'
         if image is None:
-            image = 'condaforge/mambaforge' if venv_type is not None else f"python:{python_version}-slim-bullseye"
-        target_args = ["--target", "conda-image"] if venv_type is not None else ["--target", "venv-image"]
+            image = 'condaforge/mambaforge' if is_conda else f"python:{python_version}-slim-bullseye"
+        target_args = ["--target", "conda-image"] if is_conda else ["--target", "venv-image"]
 
         run_args = ['docker', 'build', f"-f={dockerfile}", f"-t={name}", "--build-arg",
                     f"PYTHON_VERSION={python_version}", "--build-arg", f"PYTHON_IMAGE={image}",
@@ -242,7 +243,7 @@ def update(path, key, value, variable, file):
 
 
 @main.command()
-@click.option('--output', type=str, default=None)
+@click.option('-o', '--output', type=str, default=None)
 def dockerfile(output):
     """Create a Dockerfile for you to work with"""
     goldilox_path = Path(goldilox.__file__)
@@ -253,7 +254,13 @@ def dockerfile(output):
     click.echo(content)
     click.echo("##################\nDockerfile was writen to './dockerfile'\n")
     click.echo(
-        "Use 'docker build -f=Dockerfile -t=<image-name> --build-arg PIPELINE_FILE=<pipeline-path> --build-arg PYTHON_IMAGE=<base-image> .' to build a docker image")
+        "Run 'docker build -f=Dockerfile -t=<image-name> \
+            --build-arg PIPELINE_FILE=<pipeline-path> \
+            --build-arg PYTHON_VERSION=<python-version> \
+            --build-arg PYTHON_IMAGE=<base-image> \
+            --build-arg GOLDILOX_VERSION=<goldilox-version> \
+            --target <venv-image/conda-env> .'\
+            to build a docker image")
 
 
 if __name__ == '__main__':
