@@ -17,7 +17,7 @@ logger = logging.getLogger()
 
 
 class SklearnPipeline(traitlets.HasTraits, Pipeline, TransformerMixin):
-    pipeline_type = "sklearn"
+    pipeline_type = traitlets.Unicode(default_value="sklearn")
     current_time = int(time())
     created = traitlets.Int(
         default_value=current_time, allow_none=False, help="Created time"
@@ -69,7 +69,7 @@ class SklearnPipeline(traitlets.HasTraits, Pipeline, TransformerMixin):
             description="",
     ):
         """
-        :param sklearn.preprocessing.pipeline.Pipeline pipeline: The skleran pipeline
+        :param sklearn.preprocessing.pipeline.Pipeline pipeline: The sklearn pipeline
         :param raw: dict [optional]: An example of data which will be queried in production (only the features)
                 - If X is provided, would be the first row.
         :param features: list [optional]: A list of columns - if X is provided, will take it's columns
@@ -133,10 +133,15 @@ class SklearnPipeline(traitlets.HasTraits, Pipeline, TransformerMixin):
         if isinstance(df, dict):
             df = [df.copy()]
         if isinstance(df, list):
-            return pd.DataFrame(df, columns=self.features)
+            ret = pd.DataFrame(df)
+            if self.features is not None and \
+                    isinstance(ret.columns, pd.Index) and \
+                    len(self.features) == len(
+                ret.columns):
+                ret.columns = self.features
+            return ret
         try:
             import vaex
-
             if isinstance(df, vaex.dataframe.DataFrame):
                 return df.to_pandas_df()
         except:
@@ -197,6 +202,8 @@ class SklearnPipeline(traitlets.HasTraits, Pipeline, TransformerMixin):
                 X = X[self.features]
             elif len(self.features) == 1:
                 X = X[self.features[0]]
+        if self.output_columns is None:
+            self.output_columns = self.features
         return X
 
     def fit(self, df, y=None, validate=True, check_na=True):
@@ -209,6 +216,12 @@ class SklearnPipeline(traitlets.HasTraits, Pipeline, TransformerMixin):
         return self
 
     def transform(self, df, **kwargs):
+        """
+        Transform the data based on the the pipeline.
+        @param df: [DataFrame] data to tranform
+        @param kwargs: Tranform
+        @return:
+        """
         copy = self.infer(df)
         features = self.features or copy.columns
         copy = self.pipeline.transform(copy[features])
@@ -216,6 +229,17 @@ class SklearnPipeline(traitlets.HasTraits, Pipeline, TransformerMixin):
             copy = pd.DataFrame(copy, columns=features)
         return copy
 
+    def predict(self, df):
+        copy = self.infer(df)
+        features = self.features or copy.columns
+        if features is None:
+            raise RuntimeError("Model is not trained yet")
+
+        if len(features) == 1:
+            features = features[0]
+        X = copy[features] if features else copy
+        return self.pipeline.predict(X)
+
     def inference(self, df, columns=None, passthrough=True, **kwargs):
         """
         Returns the transformed data.
