@@ -182,7 +182,7 @@ def unpickle(b):
     return ret
 
 
-def get_requirements(venv_type=None, requirements=None, conda_clean=True):
+def get_requirements(venv_type=None, requirements=None, clean=True):
     """Run pip freeze  for venv and conda env export for conda
     @return requirements
     """
@@ -193,14 +193,18 @@ def get_requirements(venv_type=None, requirements=None, conda_clean=True):
     if venv_type == 'conda':
         command = ["conda env export | cut -f 1 -d '=' "]
         env = subprocess.check_output(command, shell=True).decode()
-        if conda_clean:
+        if clean:
             env = env.replace('\n  - appnope', '')
         splited = env.split('\n')
         splited[0] = 'name: conda_env'
         splited[-2] = 'prefix: conda_env'
         return '\n'.join(splited)
-    return subprocess.check_output([sys.executable, '-m', 'pip',
-                                    'freeze']).decode()
+    ret = subprocess.check_output([sys.executable, '-m', 'pip',
+                                   'freeze']).decode()
+    if clean:
+        import re
+        ret = re.sub("appnope==(.[\d \.]*)\\n", '', ret)
+    return ret
 
 
 def get_python_version():
